@@ -33,7 +33,7 @@ source ${MONASCA_LOG_API_DIR}/devstack/lib/config.sh
 ###############################################################################
 function pre_install {
     install_elk
-    install_node_nvm
+    install_nodejs
     install_gate_config_holder
 }
 
@@ -92,6 +92,26 @@ function init_monasca_log {
     create_log_management_accounts
 }
 
+function init_monasca_grafana_dashboards {
+    if is_service_enabled horizon; then
+        echo_summary "Init Grafana dashboards"
+
+        sudo python "${PLUGIN_FILES}"/grafana/grafana.py "${PLUGIN_FILES}"/grafana/dashboards.d
+    fi
+}
+
+function init_agent {
+    echo_summary "Init Monasca agent"
+
+    sudo cp -f "${PLUGIN_FILES}"/monasca-agent/http_check.yaml /etc/monasca/agent/conf.d/http_check.yaml
+    sudo cp -f "${PLUGIN_FILES}"/monasca-agent/process.yaml /etc/monasca/agent/conf.d/process.yaml
+    sudo cp -f "${PLUGIN_FILES}"/monasca-agent/elastic.yaml /etc/monasca/agent/conf.d/elastic.yaml
+
+    sudo sed -i "s/{{IP}}/$(ip -o -4 addr list eth1 | awk '{print $4}' | cut -d/ -f1 | head -1)/" /etc/monasca/agent/conf.d/*.yaml
+    sudo sed -i "s/127\.0\.0\.1/$(hostname)/" /etc/monasca/agent/conf.d/*.yaml
+    sudo systemctl restart monasca-collector
+}
+
 function stop_monasca_log {
     stop_process "monasca-log-agent" || true
     stop_monasca_log_api
@@ -120,7 +140,7 @@ function clean_monasca_log {
     clean_kibana
     clean_elasticsearch
     clean_logstash
-    clean_node_nvm
+    clean_nodejs
     clean_gate_config_holder
 }
 ###############################################################################
@@ -180,13 +200,13 @@ function configure_monasca_log_api_core {
 
     $MONASCA_LOG_API_BIN_DIR/oslo-config-generator \
         --config-file $MONASCA_LOG_API_DIR/config-generator/monasca-log-api.conf \
-        --output-file /tmp/log-api.conf
+        --output-file /tmp/monasca-log-api.conf
 
-    install -m 600 /tmp/log-api.conf $MONASCA_LOG_API_CONF && rm -rf /tmp/log-api.conf
+    install -m 600 /tmp/monasca-log-api.conf $MONASCA_LOG_API_CONF && rm -rf /tmp/monasca-log-api.conf
     install -m 600 $MONASCA_LOG_API_DIR/etc/monasca/log-api-paste.ini $MONASCA_LOG_API_PASTE
     install -m 600 $MONASCA_LOG_API_DIR/etc/monasca/log-api-logging.conf $MONASCA_LOG_API_LOGGING_CONF
 
-    # configure log-api.conf
+    # configure monasca-log-api.conf
     iniset "$MONASCA_LOG_API_CONF" DEFAULT log_config_append $MONASCA_LOG_API_LOGGING_CONF
     iniset "$MONASCA_LOG_API_CONF" service region $REGION_NAME
 
@@ -379,7 +399,7 @@ function install_elasticsearch {
         echo_summary "Installing ElasticSearch ${ELASTICSEARCH_VERSION}"
 
         local es_tarball=elasticsearch-${ELASTICSEARCH_VERSION}.tar.gz
-        local es_url=http://download.elasticsearch.org/elasticsearch/elasticsearch/${es_tarball}
+        local es_url=https://download.elastic.co/elasticsearch/release/org/elasticsearch/distribution/tar/elasticsearch/${ELASTICSEARCH_VERSION}/${es_tarball}
 
         local es_dest
         es_dest=`get_extra_file ${es_url}`
@@ -618,10 +638,8 @@ function install_log_agent {
     if is_service_enabled monasca-log-agent; then
         echo_summary "Installing monasca-log-agent [monasca-output-plugin]"
 
-        local monasca_log_agent_version=0.5.2
-        local ls_plugin_filename=logstash-output-monasca_log_api-${monasca_log_agent_version}.gem
-
-        $LOGSTASH_DIR/bin/plugin install "${PLUGIN_FILES}"/monasca-log-agent/${ls_plugin_filename}
+        $LOGSTASH_DIR/bin/plugin install --version \
+            "${LOGSTASH_OUTPUT_MONASCA_VERSION}" logstash-output-monasca_log_api
     fi
 }
 
@@ -660,38 +678,22 @@ function start_monasca_log_agent {
     fi
 }
 
-function install_node_nvm {
-    set -i
-    if [[ ! -f "${HOME}/.nvm/nvm.sh" ]] && is_service_enabled kibana; then
-        # note(trebskit) we need node to build kibana plugin
-        # so if kibana is enabled in this environment, let's install node
-        echo_summary "Install Node ${NODE_JS_VERSION} with NVM ${NVM_VERSION}"
-        local nvmUrl=https://raw.githubusercontent.com/creationix/nvm/v${NVM_VERSION}/install.sh
-
-        local nvmDest
-        nvmDest=`get_extra_file ${nvmUrl}`
-
-        bash ${nvmDest}
-    fi
+function install_nodejs {
     if is_service_enabled kibana; then
         # refresh installation
+        apt_get install nodejs npm
         (
-            source "${HOME}"/.nvm/nvm.sh >> /dev/null; \
-            nvm install ${NODE_JS_VERSION}; \
-            nvm use ${NODE_JS_VERSION}; \
             npm config set registry "http://registry.npmjs.org/"; \
             npm config set proxy "${HTTP_PROXY}"; \
             npm set strict-ssl false;
         )
     fi
-    set +i
 }
 
-function clean_node_nvm {
-    if [[ -f "${HOME}/.nvm/nvm.sh" ]] && is_service_enabled kibana; then
-        echo_summary "Cleaning Node ${NODE_JS_VERSION} with NVM ${NVM_VERSION}"
-        sudo rm ${FILES}/nvm_install.sh
-        sudo rm -rf "${HOME}/.nvm/nvm.sh"
+function clean_nodejs {
+    if is_service_enabled kibana; then
+        echo_summary "Cleaning Node.js"
+        apt_get purge nodejs npm
     fi
 }
 
@@ -712,10 +714,8 @@ function build_kibana_plugin {
         monasca_kibana_plugin_version="$(python -c 'import json; \
             obj = json.load(open("package.json")); print obj["version"]')"
 
-        set -i
-        (source "${HOME}"/.nvm/nvm.sh >> /dev/null; nvm use ${NODE_JS_VERSION}; npm install)
-        (source "${HOME}"/.nvm/nvm.sh >> /dev/null; nvm use ${NODE_JS_VERSION}; npm run package)
-        set +i
+        npm install
+        npm run package
 
         local pkg=$MONASCA_KIBANA_PLUGIN_DIR/target/monasca-kibana-plugin-${monasca_kibana_plugin_version}.tar.gz
         local easyPkg=$DEST/monasca-kibana-plugin.tar.gz
@@ -785,10 +785,15 @@ function enable_log_management {
         local localSettings=${DEST}/horizon/monitoring/config/local_settings.py
 
         sudo sed -e "
-            s|ENABLE_KIBANA_BUTTON = getattr(settings, 'ENABLE_KIBANA_BUTTON', False)|ENABLE_KIBANA_BUTTON = getattr(settings, 'ENABLE_KIBANA_BUTTON', True)|g;
             s|KIBANA_HOST = getattr(settings, 'KIBANA_HOST', 'http://192.168.10.4:5601/')|KIBANA_HOST = getattr(settings, 'KIBANA_HOST', 'http://${KIBANA_SERVICE_HOST}:${KIBANA_SERVICE_PORT}/')|g;
         " -i ${localSettings}
 
+        if is_service_enabled monasca-log-api; then
+            sudo sed -e "
+                s|'ENABLE_LOG_MANAGEMENT_BUTTON', False|'ENABLE_LOG_MANAGEMENT_BUTTON', True|g;
+            " -i ${localSettings}
+        fi
+
         restart_apache_server
     fi
 }
@@ -815,6 +820,10 @@ if is_service_enabled monasca-log; then
         # Initialize and start the Monasca service
         echo_summary "Initializing Monasca Log Management"
         init_monasca_log
+        init_monasca_grafana_dashboards
+        if is_service_enabled monasca-agent; then
+            init_agent
+        fi
         start_monasca_log
     fi
 
